@@ -77,7 +77,7 @@ import java.util.concurrent.atomic.AtomicReference;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import org.apache.commons.logging.Log;
-import com.damienmiller.BCrypt;
+import org.osgi.framework.BundleContext;
 import com.openexchange.admin.exceptions.OXGenericException;
 import com.openexchange.admin.properties.AdminProperties;
 import com.openexchange.admin.rmi.dataobjects.Context;
@@ -97,11 +97,42 @@ import com.openexchange.tools.sql.DBUtils;
 
 public class AdminCache {
 
+    private static final AtomicReference<BundleContext> BUNDLE_CONTEXT = new AtomicReference<BundleContext>();
+
+    /**
+     * Gets the <tt>BundleContext</tt>.
+     *
+     * @return The <tt>BundleContext</tt> or <code>null</code>
+     */
+    public static BundleContext getBundleContext() {
+        return BUNDLE_CONTEXT.get();
+    }
+
+    /**
+     * Atomically sets the <tt>BundleContext</tt> to the given updated <tt>BundleContext</tt> reference if the current value <tt>==</tt> the expected value.
+     *
+     * @param expect the expected <tt>BundleContext</tt>
+     * @param update the new <tt>BundleContext</tt>
+     * @return <code>true</code> if successful. <code>false</code> return indicates that the actual <tt>ConfigurationService</tt> was not equal to the expected <tt>ConfigurationService</tt>.
+     */
+    public static boolean compareAndSetBundleContext(final BundleContext expect, final BundleContext update) {
+        return BUNDLE_CONTEXT.compareAndSet(expect, update);
+    }
+
+    /**
+     * Sets the <tt>BundleContext</tt>.
+     *
+     * @param service The <tt>BundleContext</tt> to set
+     */
+    public static void setBundleContext(final BundleContext service) {
+        BUNDLE_CONTEXT.set(service);
+    }
+
     private static final AtomicReference<ConfigurationService> CONF_SERVICE = new AtomicReference<ConfigurationService>();
 
     /**
      * Gets the <tt>ConfigurationService</tt>.
-     * 
+     *
      * @return The <tt>ConfigurationService</tt> or <code>null</code>
      */
     public static ConfigurationService getConfigurationService() {
@@ -110,7 +141,7 @@ public class AdminCache {
 
     /**
      * Atomically sets the <tt>ConfigurationService</tt> to the given updated <tt>ConfigurationService</tt> reference if the current value <tt>==</tt> the expected value.
-     * 
+     *
      * @param expect the expected <tt>ConfigurationService</tt>
      * @param update the new <tt>ConfigurationService</tt>
      * @return <code>true</code> if successful. <code>false</code> return indicates that the actual <tt>ConfigurationService</tt> was not equal to the expected <tt>ConfigurationService</tt>.
@@ -121,7 +152,7 @@ public class AdminCache {
 
     /**
      * Sets the <tt>ConfigurationService</tt>.
-     * 
+     *
      * @param service The <tt>ConfigurationService</tt> to set
      */
     public static void setConfigurationService(final ConfigurationService service) {
@@ -598,32 +629,26 @@ public class AdminCache {
      * @throws UnsupportedEncodingException
      */
     public String encryptPassword(final PasswordMechObject user) throws StorageException, NoSuchAlgorithmException, UnsupportedEncodingException {
-        String passwordMech = user.getPasswordMech();
-        if (isEmpty(passwordMech) || "null".equals(toLowerCase(passwordMech))) {
+        String passwd = null;
+        if (user.getPasswordMech() == null) {
             String pwmech = getProperties().getUserProp(AdminProperties.User.DEFAULT_PASSWORD_MECHANISM, "SHA");
             pwmech = "{" + pwmech + "}";
             if (pwmech.equalsIgnoreCase(PasswordMechObject.CRYPT_MECH)) {
-                passwordMech = PasswordMechObject.CRYPT_MECH;
+                user.setPasswordMech(PasswordMechObject.CRYPT_MECH);
             } else if (pwmech.equalsIgnoreCase(PasswordMechObject.SHA_MECH)) {
-                passwordMech = PasswordMechObject.SHA_MECH;
-            } else if (pwmech.equalsIgnoreCase(PasswordMechObject.BCRYPT_MECH)) {
-                passwordMech = PasswordMechObject.BCRYPT_MECH;
+                user.setPasswordMech(PasswordMechObject.SHA_MECH);
             } else {
                 log.warn("WARNING: unknown password mechanism " + pwmech + " using SHA");
-                passwordMech = PasswordMechObject.SHA_MECH;
+                user.setPasswordMech(PasswordMechObject.SHA_MECH);
             }
         }
-        user.setPasswordMech(passwordMech);
-        final String passwd;
-        if (PasswordMechObject.CRYPT_MECH.equals(passwordMech)) {
+        if (user.getPasswordMech().equals(PasswordMechObject.CRYPT_MECH)) {
             passwd = UnixCrypt.crypt(user.getPassword());
-        } else if (PasswordMechObject.SHA_MECH.equals(passwordMech)) {
+        } else if (user.getPasswordMech().equals(PasswordMechObject.SHA_MECH)) {
             passwd = SHACrypt.makeSHAPasswd(user.getPassword());
-        } else if (PasswordMechObject.BCRYPT_MECH.equals(passwordMech)) {
-            passwd = BCrypt.hashpw(user.getPassword(), BCrypt.gensalt());
         } else {
-            log.error("unsupported password mechanism: " + passwordMech);
-            throw new StorageException("unsupported password mechanism: " + passwordMech);
+            log.error("unsupported password mechanism: " + user.getPasswordMech());
+            throw new StorageException("unsupported password mechanism: " + user.getPasswordMech());
         }
         return passwd;
     }
@@ -677,7 +702,8 @@ public class AdminCache {
             }
         }
         if (masterCredentials == null) {
-            throw new OXGenericException("No master credentials defined!");
+            final OXGenericException genericException = new OXGenericException("No master credentials defined!");
+            log.warn(genericException.getMessage());
         }
     }
 
@@ -726,34 +752,7 @@ public class AdminCache {
     }
 
     public boolean isMasterAdmin(final Credentials auth) {
-        return masterAuthenticationDisabled || getMasterCredentials().getLogin().equals(auth.getLogin());
-    }
-
-    /** ASCII-wise to lower-case */
-    private static String toLowerCase(final CharSequence chars) {
-        if (null == chars) {
-            return null;
-        }
-        final int length = chars.length();
-        final StringBuilder builder = new StringBuilder(length);
-        for (int i = 0; i < length; i++) {
-            final char c = chars.charAt(i);
-            builder.append((c >= 'A') && (c <= 'Z') ? (char) (c ^ 0x20) : c);
-        }
-        return builder.toString();
-    }
-
-    /** Check for an empty string */
-    private static boolean isEmpty(final String string) {
-        if (null == string) {
-            return true;
-        }
-        final int len = string.length();
-        boolean isWhitespace = true;
-        for (int i = 0; isWhitespace && i < len; i++) {
-            isWhitespace = Character.isWhitespace(string.charAt(i));
-        }
-        return isWhitespace;
+        return masterAuthenticationDisabled || (getMasterCredentials() != null && getMasterCredentials().getLogin().equals(auth.getLogin()));
     }
 
 }
